@@ -30,9 +30,6 @@ CONF = cfg.CONF
 
 class SchedulerRpcAPITestCase(test.TestCase):
 
-    def setUp(self):
-        super(SchedulerRpcAPITestCase, self).setUp()
-
     def tearDown(self):
         super(SchedulerRpcAPITestCase, self).tearDown()
 
@@ -91,26 +88,31 @@ class SchedulerRpcAPITestCase(test.TestCase):
         self._test_scheduler_api('get_pools',
                                  rpc_method='call',
                                  filters=None,
-                                 version='1.1')
+                                 version='1.9')
 
-    def test_create_consistency_group(self):
-        self._test_scheduler_api('create_consistency_group',
+    def test_create_share_group(self):
+        self._test_scheduler_api('create_share_group',
                                  rpc_method='cast',
-                                 cg_id='cg_id',
+                                 share_group_id='fake_share_group_id',
                                  request_spec='fake_request_spec',
                                  filter_properties='filter_properties',
-                                 version='1.3')
+                                 version='1.8')
 
     def test_migrate_share_to_host(self):
         self._test_scheduler_api('migrate_share_to_host',
-                                 rpc_method='call',
+                                 rpc_method='cast',
                                  share_id='share_id',
                                  host='host',
-                                 force_host_copy=True,
-                                 notify=True,
+                                 force_host_assisted_migration=True,
+                                 preserve_metadata=True,
+                                 writable=True,
+                                 nondisruptive=False,
+                                 preserve_snapshots=True,
+                                 new_share_network_id='fake_net_id',
+                                 new_share_type_id='fake_type_id',
                                  request_spec='fake_request_spec',
                                  filter_properties='filter_properties',
-                                 version='1.4')
+                                 version='1.7')
 
     def test_create_share_replica(self):
         self._test_scheduler_api('create_share_replica',
@@ -121,7 +123,7 @@ class SchedulerRpcAPITestCase(test.TestCase):
 
     def test_manage_share(self):
         self._test_scheduler_api('manage_share',
-                                 rpc_method='call',
+                                 rpc_method='cast',
                                  share_id='share_id',
                                  driver_options='fake_driver_options',
                                  request_spec='fake_request_spec',
