@@ -14,7 +14,7 @@
 
 from lxml import etree
 import mock
-from six.moves import urllib
+import requests
 
 from manila.share.drivers.netapp.dataontap.client import api
 
@@ -39,6 +39,7 @@ NODE_NAME = 'fake_node1'
 NODE_NAMES = ('fake_node1', 'fake_node2')
 VSERVER_NAME = 'fake_vserver'
 VSERVER_NAME_2 = 'fake_vserver_2'
+VSERVER_PEER_NAME = 'fake_vserver_peer'
 ADMIN_VSERVER_NAME = 'fake_admin_vserver'
 NODE_VSERVER_NAME = 'fake_node_vserver'
 NFS_VERSIONS = ['nfs3', 'nfs4.0']
@@ -2249,6 +2250,23 @@ CLUSTER_PEER_POLICY_GET_RESPONSE = etree.XML("""
   </results>
 """)
 
+CLUSTER_GET_CLUSTER_NAME = etree.XML("""
+  <results status="passed">
+    <attributes>
+      <cluster-identity-info>
+        <cluster-contact />
+        <cluster-location>-</cluster-location>
+        <cluster-name>%(cluster_name)s</cluster-name>
+        <cluster-serial-number>1-80-000000</cluster-serial-number>
+        <cluster-uuid>fake_uuid</cluster-uuid>
+        <rdb-uuid>fake_rdb</rdb-uuid>
+      </cluster-identity-info>
+    </attributes>
+  </results>
+""" % {
+    'cluster_name': CLUSTER_NAME,
+})
+
 VSERVER_PEER_GET_ITER_RESPONSE = etree.XML("""
   <results status="passed">
     <attributes-list>
@@ -2579,7 +2597,7 @@ FAKE_RESULT_API_ERRNO_VALID.add_attr('errno', '14956')
 FAKE_RESULT_SUCCESS = api.NaElement('result')
 FAKE_RESULT_SUCCESS.add_attr('status', 'passed')
 
-FAKE_HTTP_OPENER = urllib.request.build_opener()
+FAKE_HTTP_SESSION = requests.Session()
 
 FAKE_MANAGE_VOLUME = {
     'aggregate': SHARE_AGGREGATE_NAME,
