@@ -809,6 +809,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_1',
             'provider_location': 'should_not_be_used_1',
+            'share_name': 'share_fake_share_instance_id_1',
+            'name': 'share-snapshot-6813e06b-a8f5-4784-b17d-f3e91afa370e',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': 3,
@@ -821,6 +823,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_2',
             'provider_location': 'should_not_be_used_2',
+            'share_name': 'share_fake_share_instance_id_2',
+            'name': 'share-snapshot-1e010dfe-545b-432d-ab95-4ef03cd82f89',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': '2',
@@ -859,6 +863,8 @@ class ShareDriverTestCase(test.TestCase):
                  'share_instance_id': member['share']['id'],
                  'id': member['id'],
                  'share': member['share'],
+                 'share_name': member['share_name'],
+                 'name': member['name'],
                  'size': member['share']['size'],
                  'share_size': member['share']['size'],
                  'share_proto': member['share']['share_proto'],
@@ -881,6 +887,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_1',
             'provider_location': 'should_not_be_used_1',
+            'share_name': 'share_fake_share_instance_id_1',
+            'name': 'share-snapshot-6813e06b-a8f5-4784-b17d-f3e91afa370e',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': 3,
@@ -893,6 +901,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_2',
             'provider_location': 'should_not_be_used_2',
+            'share_name': 'share_fake_share_instance_id_2',
+            'name': 'share-snapshot-1e010dfe-545b-432d-ab95-4ef03cd82f89',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': '2',
@@ -932,6 +942,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_instance_id': fake_snap_member_1['share']['id'],
             'id': fake_snap_member_1['id'],
             'share': fake_snap_member_1['share'],
+            'share_name': fake_snap_member_1['share_name'],
+            'name': fake_snap_member_1['name'],
             'size': fake_snap_member_1['share']['size'],
             'share_size': fake_snap_member_1['share']['size'],
             'share_proto': fake_snap_member_1['share']['share_proto'],
@@ -945,6 +957,8 @@ class ShareDriverTestCase(test.TestCase):
                  'share_instance_id': member['share']['id'],
                  'id': member['id'],
                  'share': member['share'],
+                 'share_name': member['share_name'],
+                 'name': member['name'],
                  'size': member['share']['size'],
                  'share_size': member['share']['size'],
                  'share_proto': member['share']['share_proto'],
@@ -1020,6 +1034,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_1',
             'provider_location': 'fake_provider_location_2',
+            'share_name': 'share_fake_share_instance_id_1',
+            'name': 'share-snapshot-6813e06b-a8f5-4784-b17d-f3e91afa370e',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': 3,
@@ -1032,6 +1048,8 @@ class ShareDriverTestCase(test.TestCase):
             'share_group_snapshot_id': 'fake_share_group_snapshot_id',
             'share_instance_id': 'fake_share_instance_id_2',
             'provider_location': 'fake_provider_location_2',
+            'share_name': 'share_fake_provider_location_2',
+            'name': 'share-snapshot-1e010dfe-545b-432d-ab95-4ef03cd82f89',
             'share': {
                 'id': '420f978b-dbf6-4b3c-92fe-f5b17a0bb5e2',
                 'size': '2',
@@ -1070,6 +1088,8 @@ class ShareDriverTestCase(test.TestCase):
                  'share': member['share'],
                  'size': member['share']['size'],
                  'share_size': member['share']['size'],
+                 'share_name': member['share_name'],
+                 'name': member['name'],
                  'share_proto': member['share']['share_proto'],
                  'provider_location': member['provider_location']},
                 share_server=None)
